function A = uniformSampling(matZ,samples)
% uniformSampling - uniformly creates samples within a matrix zonotope
%
% Syntax:  
%    A = uniformSampling(matZ,samples)
%
% Inputs:
%    matZ - matrix zonotope
%    samples - number of segments
%
% Outputs:
%    A - cell array of matrices
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: none

% Author:       Matthias Althoff
% Written:      23-June-2010
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------


%generate sample matrices
A=cell(samples,1);
for i=1:samples
    %initialize random matrix
    A{i}=matZ.center;
    %add generator matrices
    for iGen=1:matZ.gens
        A{i}=A{i} + (2*rand(1)-1).*matZ.generator{iGen};
    end
end

    
%------------- END OF CODE --------------